# TXM_Sandbox
This is a GUI program based on Jupyter that integrates tomography reconstruction and 2D/3D XANES data analysis. It provides a mechanism that allows users to customize the input data file formats.

Installation
via conda-forge

conda create -n pytxm python=3.10
conda activate pytxm
conda install TXM_Sandbox -c conda-forge


Please cite these two papers if you use TXM_Sandbox in your works.

1. Xiao, X., Xu, Z., Lin, F. & Lee, W.-K. (2022). J. Synchrotron Rad. 29, 266-275. https://doi.org/10.1107/S1600577521011978

2. Xiao, X., Xu, Z., Hou, D., Yang, Z. & Lin, F. (2022). J. Synchrotron Rad. 29, 1085-1094. https://doi.org/10.1107/S1600577522005598
 
